@@ -90,34 +90,37 @@
 #'
 #' @importFrom kde1d dkde1d pkde1d qkde1d
 #' @export
-vine <- function(data,
-                 margins_controls = list(
-                   mult = NULL,
-                   xmin = NaN,
-                   xmax = NaN,
-                   bw = NA,
-                   deg = 2
-                 ),
-                 copula_controls = list(
-                   family_set = "all",
-                   structure = NA,
-                   par_method = "mle",
-                   nonpar_method = "constant",
-                   mult = 1,
-                   selcrit = "aic",
-                   psi0 = 0.9,
-                   presel = TRUE,
-                   allow_rotations = TRUE,
-                   trunc_lvl = Inf,
-                   tree_crit = "tau",
-                   threshold = 0,
-                   keep_data = FALSE,
-                   show_trace = FALSE,
-                   cores = 1
-                 ),
-                 weights = numeric(),
-                 keep_data = FALSE,
-                 cores = 1) {
+vine <- function(
+  data,
+  margins_controls = list(
+    mult = NULL,
+    xmin = NaN,
+    xmax = NaN,
+    bw = NA,
+    deg = 2
+  ),
+  copula_controls = list(
+    family_set = "all",
+    structure = NA,
+    par_method = "mle",
+    nonpar_method = "constant",
+    mult = 1,
+    selcrit = "aic",
+    psi0 = 0.9,
+    presel = TRUE,
+    allow_rotations = TRUE,
+    trunc_lvl = Inf,
+    tree_crit = "tau",
+    threshold = 0,
+    keep_data = FALSE,
+    show_trace = FALSE,
+    cores = 1,
+    tree_algorithm = "mst_prim"
+  ),
+  weights = numeric(),
+  keep_data = FALSE,
+  cores = 1
+) {
   ## basic sanity checks (copula_controls are checked by vinecop)
   data <- expand_factors(data)
 
@@ -145,15 +148,17 @@ vine <- function(data,
 
   ## estimation of the marginals
   vine <- list()
-  vine$margins <- fit_margins_cpp(prep_for_margins(data),
-                                  xmin = margins_controls$xmin,
-                                  xmax = margins_controls$xmax,
-                                  type = margins_controls$type,
-                                  mult = margins_controls$mult,
-                                  bw = margins_controls$bw,
-                                  deg = margins_controls$deg,
-                                  weights = weights,
-                                  cores)
+  vine$margins <- fit_margins_cpp(
+    prep_for_margins(data),
+    xmin = margins_controls$xmin,
+    xmax = margins_controls$xmax,
+    type = margins_controls$type,
+    mult = margins_controls$mult,
+    bw = margins_controls$bw,
+    deg = margins_controls$deg,
+    weights = weights,
+    cores
+  )
   vine$margins_controls <- margins_controls
   vine$margins <- finalize_margins(data, vine$margins)
 
@@ -163,7 +168,9 @@ vine <- function(data,
   copula_controls$data <- compute_pseudo_obs(data, vine)
   copula_controls$weights <- weights
   vine$copula <- do.call(vinecop, copula_controls)
-  vine$copula_controls <- copula_controls[-which(names(copula_controls) == "data")]
+  vine$copula_controls <- copula_controls[
+    -which(names(copula_controls) == "data")
+  ]
 
   finalize_vine(vine, data, weights, keep_data)
 }
@@ -192,9 +199,10 @@ compute_pseudo_obs <- function(data, vine) {
 expand_factors <- function(data) {
   if (is.data.frame(data)) {
     data <- lapply(data, function(x) {
-      if (is.numeric(x) | is.ordered(x))
+      if (is.numeric(x) | is.ordered(x)) {
         return(x)
-      x <- model.matrix(~ x)[, -1, drop = FALSE]
+      }
+      x <- model.matrix(~x)[, -1, drop = FALSE]
       x <- as.data.frame(x)
       x <- lapply(x, function(y) ordered(y, levels = 0:1))
     })
@@ -236,10 +244,17 @@ vine_dist <- function(margins, pair_copulas, structure) {
   is_ok <- sapply(check_marg, isTRUE)
   if (!all(is_ok)) {
     msg <- "Some objects in marg aren't properly defined.\n"
-    msg <- c(msg, paste0("margin ", seq_along(check_marg)[!is_ok], " : ",
-                         unlist(check_marg[!is_ok]), ".",
-                         sep = "\n"
-    ))
+    msg <- c(
+      msg,
+      paste0(
+        "margin ",
+        seq_along(check_marg)[!is_ok],
+        " : ",
+        unlist(check_marg[!is_ok]),
+        ".",
+        sep = "\n"
+      )
+    )
     stop(msg)
   }
 
@@ -247,12 +262,15 @@ vine_dist <- function(margins, pair_copulas, structure) {
   copula <- vinecop_dist(pair_copulas, structure)
 
   # create object
-  structure(list(
-    margins = margins,
-    copula = copula,
-    npars = copula$npars + npars_marg,
-    loglik = NA
-  ), class = "vine_dist")
+  structure(
+    list(
+      margins = margins,
+      copula = copula,
+      npars = copula$npars + npars_marg,
+      loglik = NA
+    ),
+    class = "vine_dist"
+  )
 }
 
 expand_margin_controls <- function(controls, d, data) {
@@ -263,8 +281,9 @@ expand_margin_controls <- function(controls, d, data) {
     controls[["mult"]] <- log(1 + d)
   }
   for (par in names(controls)) {
-    if (length(controls[[par]]) != ncol(data))
+    if (length(controls[[par]]) != ncol(data)) {
       controls[[par]] <- rep(controls[[par]], ncol(data))
+    }
   }
   controls
 }
