@@ -33,6 +33,16 @@
 #' @param var_types variable types, a length d vector; e.g., `c("c", "c")` for
 #'   two continuous variables, or `c("c", "d")` for first variable continuous
 #'   and second discrete.
+#' @param tree_algorithm The algorithm for building the spanning
+#'   tree (`"mst_prim"`, `"mst_kruskal"`, `"random_weighted"`, or
+#'   `"random_unweighted"`) during the tree-wise structure selection.
+#'   `"mst_prim"` and `"mst_kruskal"` use Prim's and Kruskal's algorithms
+#'   respectively to select the maximum spanning tree, maximizing
+#'   the sum of the edge weights (i.e., `tree_criterion`).
+#'   `"random_weighted"` and `"random_unweighted"` use Wilson's
+#'   algorithm to generate a random spanning tree, either with probability
+#'   proportional to the product of the edge weights (weighted) or
+#'   uniformly (unweighted).
 #'
 #' @details
 #'
@@ -55,6 +65,29 @@
 #' limit and the cdf itself coincide. Respective columns can be omitted in the
 #' second block.
 #'
+#' ## Structure selection
+#'
+#' Selection of the structure is performed using the algorithm of
+#' Dissmann, J. F., E. C. Brechmann, C. Czado, and D. Kurowicka (2013).
+#' *Selecting and estimating regular vine copulae and application to
+#' financial returns.* Computational Statistics & Data Analysis, 59 (1),
+#' 52-69.
+#' The dependence measure used to select trees (default: Kendall's tau) is
+#' corrected for ties and can be changed using the `tree_criterion`
+#' argument, which can be set to `"tau"`, `"rho"` or `"hoeffd"`.
+#' Both Prim's (default: `"mst_prim"`) and Kruskal's ()`"mst_kruskal"`)
+#' algorithms are available through `tree_algorithm` to set the
+#' maximum spanning tree selection algorithm.
+#' An alternative to the maximum spanning tree selection is to use random
+#' spanning trees, which can be selected using `controls.tree_algorithm` and
+#' come in two flavors, both using Wilson's algorithm loop erased random walks:
+#'
+#'   - "random_weighted"` generates a random spanning tree with probability
+#'     proportional to the product of the weights (i.e., the dependence) of
+#'     the edges in the tree.
+#'   - "random_unweighted"` generates a random spanning tree uniformly over all
+#'     spanning trees satisfying the proximity condition.
+#'
 #' ## Partial structure selection
 #'
 #' It is possible to fix the vine structure only in the first trees and select
@@ -123,14 +156,28 @@
 #' # we require two types of observations (see Details)
 #' u_disc <- cbind(ppois(x, 1), u[, 2:5], ppois(x - 1, 1))
 #' fit <- vinecop(u_disc, var_types = c("d", rep("c", 4)))
-vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
-                    structure = NA, par_method = "mle",
-                    nonpar_method = "constant", mult = 1, selcrit = "aic",
-                    weights = numeric(), psi0 = 0.9, presel = TRUE,
-                    allow_rotations = TRUE,
-                    trunc_lvl = Inf, tree_crit = "tau", threshold = 0,
-                    keep_data = FALSE, vinecop_object = NULL,
-                    show_trace = FALSE, cores = 1) {
+vinecop <- function(
+  data,
+  var_types = rep("c", NCOL(data)),
+  family_set = "all",
+  structure = NA,
+  par_method = "mle",
+  nonpar_method = "constant",
+  mult = 1,
+  selcrit = "aic",
+  weights = numeric(),
+  psi0 = 0.9,
+  presel = TRUE,
+  allow_rotations = TRUE,
+  trunc_lvl = Inf,
+  tree_crit = "tau",
+  threshold = 0,
+  keep_data = FALSE,
+  vinecop_object = NULL,
+  show_trace = FALSE,
+  cores = 1,
+  tree_algorithm = "mst_prim"
+) {
   assert_that(
     is.character(family_set),
     inherits(structure, "matrix") ||
@@ -138,26 +185,34 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
       (is.scalar(structure) && is.na(structure)),
     is.string(par_method),
     is.string(nonpar_method),
-    is.number(mult), mult > 0,
+    is.number(mult),
+    mult > 0,
     is.string(selcrit),
     is.numeric(weights),
-    is.number(psi0), psi0 > 0, psi0 < 1,
+    is.number(psi0),
+    psi0 > 0,
+    psi0 < 1,
     is.flag(presel),
     is.flag(allow_rotations),
     is.scalar(trunc_lvl),
     is.string(tree_crit),
     is.scalar(threshold),
     is.flag(keep_data),
-    is.number(cores), cores > 0,
-    correct_var_types(var_types)
+    is.number(cores),
+    cores > 0,
+    correct_var_types(var_types),
+    is.string(tree_algorithm)
   )
 
+  seeds <- get_seeds()
   if (!is.null(vinecop_object)) {
     if (!inherits(vinecop_object, "vinecop")) {
       stop("'vinecop_object' must be of class 'vinecop'")
     }
     if (!identical(structure, NA) || !identical(family_set, "all")) {
-      warning("'structure' and 'family_set' are ignored when 'vinecop_object' is provided")
+      warning(
+        "'structure' and 'family_set' are ignored when 'vinecop_object' is provided"
+      )
     }
     vinecop <- vinecop_fit_cpp(
       data = as.matrix(data),
@@ -167,7 +222,9 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
       mult = mult,
       weights = weights,
       show_trace = show_trace,
-      num_threads = cores
+      num_threads = cores,
+      tree_algorithm = tree_algorithm,
+      seeds = seeds
     )
   } else {
     # check if families known (w/ partial matching) and expand convenience defs
@@ -192,7 +249,8 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
       weights = weights,
       psi0 = psi0,
       preselect_families = presel,
-      truncation_level = ifelse( # Inf cannot be passed to C++
+      truncation_level = ifelse(
+        # Inf cannot be passed to C++
         is.finite(trunc_lvl),
         trunc_lvl,
         .Machine$integer.max
@@ -205,11 +263,12 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
       allow_rotations = allow_rotations,
       show_trace = show_trace,
       num_threads = cores,
-      var_types = var_types
+      var_types = var_types,
+      tree_algorithm = tree_algorithm,
+      seeds = seeds
     )
   }
 
-
   ## make all pair-copulas bicop objects
   vinecop$pair_copulas <- lapply(
     vinecop$pair_copulas,
@@ -232,7 +291,8 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
     allow_rotations = allow_rotations,
     trunc_lvl = trunc_lvl,
     tree_crit = tree_crit,
-    threshold = threshold
+    threshold = threshold,
+    tree_algorithm = tree_algorithm
   )
   vinecop$nobs <- NROW(data)
   vinecop
@@ -286,8 +346,11 @@ vinecop <- function(data, var_types = rep("c", NCOL(data)), family_set = "all",
 #'
 #' # simulate from the model
 #' pairs(rvinecop(200, vc))
-vinecop_dist <- function(pair_copulas, structure,
-                         var_types = rep("c", dim(structure)[1])) {
+vinecop_dist <- function(
+  pair_copulas,
+  structure,
+  var_types = rep("c", dim(structure)[1])
+) {
   # create object
   vinecop <- structure(
     list(
