@@ -211,8 +211,8 @@ Eigen::VectorXd vinecop_cdf_cpp(const Eigen::MatrixXd& u,
 }
 
 // [[Rcpp::export()]]
-Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd& data,
-                              Rcpp::List& structure,
+Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd &data,
+                              Rcpp::List &structure,
                               std::vector<std::string> family_set,
                               std::string par_method,
                               std::string nonpar_method,
@@ -221,7 +221,7 @@ Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd& data,
                               std::string tree_criterion,
                               double threshold,
                               std::string selection_criterion,
-                              const Eigen::VectorXd& weights,
+                              const Eigen::VectorXd &weights,
                               double psi0,
                               bool select_truncation_level,
                               bool select_threshold,
@@ -230,7 +230,9 @@ Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd& data,
                               bool allow_rotations,
                               bool show_trace,
                               size_t num_threads,
-                              std::vector<std::string> var_types)
+                              std::vector<std::string> var_types,
+                              std::string tree_algorithm,
+                              std::vector<int> seeds)
 {
   std::vector<BicopFamily> fam_set(family_set.size());
   for (unsigned int fam = 0; fam < fam_set.size(); ++fam) {
@@ -255,6 +257,8 @@ Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd& data,
   fit_controls.set_select_trunc_lvl(select_truncation_level);
   fit_controls.set_select_families(select_families);
   fit_controls.set_show_trace(show_trace);
+  fit_controls.set_tree_algorithm(tree_algorithm);
+  fit_controls.set_seeds(seeds);
 
   Vinecop vinecop_cpp(rvine_structure_wrap(structure, false));
   vinecop_cpp.set_var_types(var_types);
@@ -264,14 +268,16 @@ Rcpp::List vinecop_select_cpp(const Eigen::MatrixXd& data,
 }
 
 // [[Rcpp::export()]]
-Rcpp::List vinecop_fit_cpp(const Eigen::MatrixXd& data,
-                              Rcpp::List& vinecop_r,
-                              std::string par_method,
-                              std::string nonpar_method,
-                              double mult,
-                              const Eigen::VectorXd& weights,
-                              bool show_trace,
-                              size_t num_threads)
+Rcpp::List vinecop_fit_cpp(const Eigen::MatrixXd &data,
+                           Rcpp::List &vinecop_r,
+                           std::string par_method,
+                           std::string nonpar_method,
+                           double mult,
+                           const Eigen::VectorXd &weights,
+                           bool show_trace,
+                           size_t num_threads,
+                           std::string tree_algorithm,
+                           std::vector<int> seeds)
 {
   FitControlsVinecop fit_controls;
   fit_controls.set_parametric_method(par_method);
@@ -280,6 +286,8 @@ Rcpp::List vinecop_fit_cpp(const Eigen::MatrixXd& data,
   fit_controls.set_weights(weights);
   fit_controls.set_show_trace(show_trace);
   fit_controls.set_num_threads(num_threads);
+  fit_controls.set_tree_algorithm(tree_algorithm);
+  fit_controls.set_seeds(seeds);
 
   Vinecop vinecop_cpp = vinecop_wrap(vinecop_r, false);
   vinecop_cpp.fit(data, fit_controls);
