@@ -14,8 +14,17 @@ test_that("returns proper 'bicop' object", {
   expect_s3_class(fit, "bicop_dist")
   expect_identical(
     names(fit),
-    c("family", "rotation", "parameters", "var_types",
-      "npars", "loglik", "data", "controls", "nobs")
+    c(
+      "family",
+      "rotation",
+      "parameters",
+      "var_types",
+      "npars",
+      "loglik",
+      "data",
+      "controls",
+      "nobs"
+    )
   )
 
   fit <- bicop(u, family = "tll", keep_data = FALSE)
@@ -23,15 +32,32 @@ test_that("returns proper 'bicop' object", {
   expect_s3_class(fit, "bicop_dist")
   expect_identical(
     names(fit),
-    c("family", "rotation", "parameters", "var_types",
-      "npars", "loglik", "controls", "nobs")
+    c(
+      "family",
+      "rotation",
+      "parameters",
+      "var_types",
+      "npars",
+      "loglik",
+      "controls",
+      "nobs"
+    )
   )
 
   colnames(u) <- paste(1:2)
   expect_identical(
     names(bicop(u, family = "indep")),
-    c("family", "rotation", "parameters", "var_types",
-      "npars", "loglik", "names", "controls", "nobs")
+    c(
+      "family",
+      "rotation",
+      "parameters",
+      "var_types",
+      "npars",
+      "loglik",
+      "names",
+      "controls",
+      "nobs"
+    )
   )
 })
 
